@@ -1,4 +1,5 @@
 use oxigraph::sparql;
+use oxigraph::model;
 
 use std::io;
 use std::sync::mpsc::RecvError;
@@ -8,7 +9,9 @@ use std::sync::mpsc::RecvError;
 pub enum ReasonableError {
     ManagerError(String),
     IO(io::Error),
-    Parse(sparql::ParseError),
+    SPARQLParse(sparql::ParseError),
+    IriParse(model::IriParseError),
+    BNodeParse(model::BlankNodeIdParseError),
     Eval(sparql::EvaluationError),
     SQLite(rusqlite::Error),
     ChannelRecv(RecvError),
@@ -19,7 +22,9 @@ pub enum ReasonableError {
 pub enum ReasonableError {
     ManagerError(String),
     IO(io::Error),
-    Parse(sparql::ParseError),
+    SPARQLParse(sparql::ParseError),
+    IriParse(model::IriParseError),
+    BNodeParse(model::BlankNodeIdParseError),
     Eval(sparql::EvaluationError),
     ChannelRecv(RecvError),
 }
@@ -32,7 +37,7 @@ impl From<io::Error> for ReasonableError {
 
 impl From<sparql::ParseError> for ReasonableError {
     fn from(err: sparql::ParseError) -> ReasonableError {
-        ReasonableError::Parse(err)
+        ReasonableError::SPARQLParse(err)
     }
 }
 
@@ -42,6 +47,18 @@ impl From<sparql::EvaluationError> for ReasonableError {
     }
 }
 
+impl From<model::IriParseError> for ReasonableError {
+    fn from(err: model::IriParseError) -> ReasonableError {
+        ReasonableError::IriParse(err)
+    }
+}
+
+impl From<model::BlankNodeIdParseError> for ReasonableError {
+    fn from(err: model::BlankNodeIdParseError) -> ReasonableError {
+        ReasonableError::BNodeParse(err)
+    }
+}
+
 #[cfg(feature = "sqlite")]
 impl From<rusqlite::Error> for ReasonableError {
     fn from(err: rusqlite::Error) -> ReasonableError {
