@@ -5,7 +5,7 @@
 //! website.
 #[macro_use]
 #[allow(dead_code, unused_macros)]
-mod common;
+pub mod common;
 mod disjoint_sets;
 pub mod error;
 #[allow(dead_code)]
